@@ -1,6 +1,6 @@
 package Mojo::Redis;
 
-our $VERSION = eval '0.99';
+our $VERSION = eval '0.9901';
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Mojo::IOLoop;
@@ -311,73 +311,96 @@ __END__
 
 =head1 NAME
 
-Mojo::Redis - asynchronous Redis client for L<Mojolicious>.
+Mojo::Redis - Asynchronous Redis client for L<Mojolicious>.
 
 =head1 SYNOPSIS
 
-    use Mojo::Redis;
+  use Mojo::Redis;
 
-    my $redis = Mojo::Redis->new(server => '127.0.0.1:6379');
+  my $redis = Mojo::Redis->new(server => '127.0.0.1:6379');
 
-    # Execute some commands
-    $redis->ping(
-        sub {
-            my ($redis, $res) = @_;
+  # Execute some commands
+  $redis->ping(
+    sub {
+      my ($redis, $res) = @_;
+      if (defined $res) {
+        print "Got result: ", $res->[0], "\n";
+      }
+    }
+  );
 
-            if (defined $res) {
-                print "Got result: ", $res->[0], "\n";
-            }
-        }
-    );
+  # Work with keys
+  # Ommitting the callback still makes it non-blocking and "error" events
+  # will be called if something terrible goes wrong.
+  $redis->set(key => 'value');
 
-    # Work with keys
-    $redis->set(key => 'value');
+  $redis->get(
+    key => sub {
+      my ($redis, $res) = @_;
+      print "Value of 'key' is $res\n";
+    }
+  );
 
-    $redis->get(
-        key => sub {
-            my ($redis, $res) = @_;
+  # Cleanup connection
+  $redis->quit(sub { shift->ioloop->stop });
 
-            print "Value of 'key' is $res\n";
-        }
-    );
-
-
-    # Cleanup connection
-    $redis->quit(sub { shift->ioloop->stop });
-
-    # Start IOLoop (in case it is not started yet)
-    $redis->ioloop->start;
+  # Start IOLoop (in case it is not started yet)
+  $redis->ioloop->start;
 
 Create new Mojo::IOLoop instance if you need to get blocked in a Mojolicious
 application.
 
-    use Mojolicious::Lite;
-    use Mojo::Redis;
+  use Mojolicious::Lite;
+  use Mojo::Redis;
 
-    get '/' => sub {
-        my $self = shift;
+  get '/user' => sub {
+    my $self = shift->render_later;
+    my $uid = $self->session('uid');
+    my $redis = Mojo::Redis->new;
 
-        my $redis = Mojo::Redis->new(ioloop => Mojo::IOLoop->new);
+    Mojo::IOLoop->delay(
+      sub {
+        my ($delay) = @_;
+        $redis->hgetall("user:$uid", $delay->begin);
+      },
+      sub {
+        my ($delay, $user) = @_;
+        $self->render_json($user);
+      },
+    );
+  };
 
-        my $value;
+  websocket '/messages' => sub {
+    my $self = shift;
+    my $tx = $self->tx;
+    my $pub = Mojo::Redis->new;
+    my $sub = $pub->subscribe('messages');
 
-        $redis->set(foo => 'bar')->get(
-            foo => sub {
-                my ($redis, $result) = @_;
+    # message from redis
+    $sub->on(message => sub {
+      my ($sub, $channel, $message) = @_; # $channel == messages
+      $tx->send($message);
+    });
 
-                $redis->quit->ioloop->stop;
-                $value = $result->[0];
-            }
-        )->ioloop->start;
+    # message from websocket
+    $self->on(message => sub {
+      my ($self, $message) = @_;
+      $pub->publish(messages => $message);
+    });
 
-        $self->render(text => qq(Foo value is "$value"));
-    };
+    # need to clean up after websocket close
+    $self->on(finish => sub {
+      undef $pub;
+      undef $sub;
+      undef $tx;
+    });
+  };
 
-    app->start;
+  app->start;
 
 =head1 DESCRIPTION
 
-L<Mojo::Redis> is an asynchronous client to Redis for Mojo.
+L<Mojo::Redis> is an asynchronous client to L<Redis|http://redis.io> for Mojo.
 
 =head1 EVENTS
 
@@ -486,27 +509,6 @@ the L</error> event.
 
 =head1 REDIS METHODS
 
-=head2 subscribe
-
-It's possible to subscribe in two ways:
-
-   $self = $redis->subscribe('foo','bar' => sub {
-     my ($redis, $data) = @_;
-   });
-
-The above code will overtake the current connection (if any) and put this
-object into a pure subscribe mode.
-
-   $sub = $redis->subscribe('foo','bar')->on(data => sub {
-            my ($sub, $data) = @_;
-          });
-
-Opens up a new connection that subscribes to the given pubsub channels.
-Returns an instance of L<Mojo::Redis::Subscription>. The existing C<$redis>
-object can still be used to L</get> data as expected.
-
-=head1 REDIS METHODS
-
 =head2 append
 
 =head2 auth
@@ -703,6 +705,25 @@ object can still be used to L</get> data as expected.
 
 =head2 strlen
 
+=head2 subscribe
+
+It's possible to subscribe in two ways:
+
+   $self = $redis->subscribe('foo','bar' => sub {
+     my ($redis, $data) = @_;
+   });
+
+The above code will overtake the current connection (if any) and put this
+object into a pure subscribe mode.
+
+   $sub = $redis->subscribe('foo','bar')->on(data => sub {
+            my ($sub, $data) = @_;
+          });
+
+Opens up a new connection that subscribes to the given pubsub channels.
+Returns an instance of L<Mojo::Redis::Subscription>. The existing C<$redis>
+object can still be used to L</get> data as expected.
+
 =head2 sunion
 
 =head2 sunionstore
@@ -755,22 +776,16 @@ L<Protocol::Redis>, L<Mojolicious>, L<Mojo::IOLoop>
 
 =head1 SUPPORT
 
-=head2 IRC
-
-    #mojo on irc.perl.org
-
-=head1 DEVELOPMENT
-
-=head2 Repository
-
-    https://github.com/und3f/mojox-redis
+You can contact the developers "marcus" and "batman" on IRC:
+L<irc://irc.perl.org:6667/#mojo> (#mojo on irc.perl.org)
 
 =head1 AUTHOR
 
 Sergey Zasenko, C<undef@cpan.org>.
 
 Forked from MojoX::Redis and updated to new IOLoop API by
-Marcus Ramberg C<mramberg@cpan.org>.
+Marcus Ramberg C<mramberg@cpan.org>
+and Jan Henning Thorsen C<jhthorsen@cpan.org>.
 
 =head1 COPYRIGHT AND LICENSE
 
